@@ -17,17 +17,16 @@ class TokenManager(models.Manager):
 
 
 class Token(models.Model):
-    user = models.ForeignKey(
-            User)
+    user = models.ForeignKey(User)
     token = models.CharField(
-            blank=True,
-            null=True,
-            max_length=40)
+        blank=True,
+        null=True,
+        max_length=40)
     expires = models.DateTimeField()
     next = models.CharField(
-            max_length=255,
-            blank=True,
-            null=True)
+        max_length=255,
+        blank=True,
+        null=True)
 
     objects = TokenManager()
 
@@ -39,7 +38,7 @@ class Token(models.Model):
         if self.expires is None:
             self.expires = dt.now() + td(seconds=conf.EXPIRES)
         # set the token
-        if self.token == None or self.token == '':
+        if self.token is None or self.token == '':
             seed = ''.join(choice(letters) for x in range(10))
             self.token = sha1(seed).hexdigest()
         super(Token, self).save(*args, **kwargs)
@@ -47,13 +46,6 @@ class Token(models.Model):
 #
 # connect the receivers
 models.signals.post_save.connect(
-        receivers.set_deletion_task,
-        sender=Token,
-        dispatch_uid='receivers_set_deletion_task')
-#
-#
-# connect the receivers
-models.signals.post_save.connect(
-        receivers.send_email,
-        sender=Token,
-        dispatch_uid='receivers_send_email')
+    receivers.send_email,
+    sender=Token,
+    dispatch_uid='receivers_send_email')
