@@ -9,6 +9,7 @@ class ReceiverTestCaseEmail(TestCase):
 
     def test_no_email_when_silent(self):
         """when a token is created an email is sent"""
+        self.assertEqual(0, len(mail.outbox))
         # create a user
         u = User()
         u.is_active = True
@@ -17,7 +18,7 @@ class ReceiverTestCaseEmail(TestCase):
         # create a token
         t = Token()
         t.user = u
-        t.slient = True
+        t.silent = True
         t.save()
         # now there is one message
         self.assertEqual(0, len(mail.outbox))
